@@ -70,7 +70,10 @@ def build_chain(links_names: List[str]):
     link = None
     links = []
     for link_name in links_names[::-1]:
-        link = instantiate_class(link_name, link)
+        if isinstance(link_name, str):
+            link = instantiate_class(link_name, link)
+        else:
+            link = link_name(link)
         links.append(link)
     return links[::-1]
 
@@ -95,3 +98,15 @@ class BaseDirector(object):
         self._links_names = links_names
         self._links = build_chain(links_names)
         self._first_loader = self._links[0] if len(self._links) > 0 else []
+
+    def on_start(self):
+        for link in self._links:
+            link.on_start()
+
+    def execute(self, *args, **kwargs):
+        for link in self._links:
+            link.handle(*args, **kwargs)
+
+    def on_stop(self):
+        for link in self._links:
+            link.on_stop()
